Learn R Programming

BayesDLMfMRI (version 0.0.3)

.distanceNeighbors: .distanceNeighbors

Description

this is an internal function

Usage

.distanceNeighbors(posi.refer, r1)

Arguments

posi.refer

the position of the voxel in the brain image.

r1

a positive integer number that defines the distance from every voxel with its most distant neighbor. This value determines the size of the cluster. The users can set a range of different r values: r = 0, 1, 2, 3, 4, which leads to q = 1, 7, 19, 27, 33, where q is the size of the cluster.

Details

this is an internal function

References

CARDONAJIMENEZ2021107297BayesDLMfMRI

cardona2021bayesdlmfmriBayesDLMfMRI