Learn R Programming

BayesDLMfMRI (version 0.0.3)

mask: A 3D array that works as a brain of reference (MNI atlas).

Description

A 3D array that works as a brain of reference (MNI atlas) for the group analysis.

Usage

mask

Arguments

Format

An object of class nifti of dimension 91 x 109 x 91.

Examples

Run this code
data("mask", package="BayesDLMfMRI")

Run the code above in your browser using DataLab