Learn R Programming

BayesDLMfMRI (version 0.0.3)

print.fMRI_group_evidence: print.fMRI_group_evidence

Description

Print the structure of the object related to the ffdGroupEvidence* functions.

Usage

# S3 method for fMRI_group_evidence
print(x, ...)

Arguments

x

is the returned value of any of the ffdGroupEvidence* functions

...

Other potential arguments

Details

Print the structure of the object related to the ffdGroupEvidence* functions.

Examples

Run this code
if (FALSE) {
DatabaseGroup <- get_example_fMRI_data_group()
data("covariates", package="BayesDLMfMRI")
data("mask", package="BayesDLMfMRI")
res <- ffdGroupEvidenceFETS(ffdGroup = DatabaseGroup, covariates = Covariates, 
                            m0 = 0, Cova = 100, delta = 0.95, S0 = 1, 
                            n0 = 1, N1 = FALSE, Nsimu1 = 100, Cutpos=30, 
                            r1 = 1, Test = "JointTest", mask = mask, Ncores = 7)
print(res)
}

Run the code above in your browser using DataLab