Learn R Programming

BayesDLMfMRI (version 0.0.3)

print.fMRI_group_single_voxel: print.fMRI_group_single_voxel

Description

Print the structure of the object related to the SingleVoxel* functions.

Usage

# S3 method for fMRI_group_single_voxel
print(x, ...)

Arguments

x

is the returned value of any of the GroupSingleVoxel* functions

...

Other potential arguments

Details

Print the structure of the object related to the GroupSingleVoxel* functions.

Examples

Run this code
if (FALSE) {
DatabaseGroup <- get_example_fMRI_data_group()
data("covariates", package="BayesDLMfMRI")
res <- GroupSingleVoxelFFBS(posi.ffd = c(14, 56, 40), DatabaseGroup,
                            covariates = Covariates, m0 = 0, Cova = 100, 
                            delta = 0.95, S0 = 1, n0 = 1, N1 = FALSE, 
                            Nsimu1 = 100, r1 = 1, Cutpos = 30)
print(res)
}

Run the code above in your browser using DataLab